==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/ru.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Уведомления об обновлениях",
    "Could not start updater, please try the manual update" : "Не удалось обновить. Пожалуйста, выполните обновление вручную.",
    "{version} is available. Get more information on how to update." : "Доступна версия {version}. Получить дополнительную информацию о порядке обновления.",
    "Channel updated" : "Канал обновлен.",
    "The update server could not be reached since %d days to check for new updates." : "Сервер обновлений недоступен для проверки наличия обновлений дней: %d.",
    "Please check the Nextcloud and server log files for errors." : "Проверьте наличие ошибок в файлах журналов Nextcloud и сервера.",
    "Update to %1$s is available." : "Доступно обновлений: %1$s",
    "Update for %1$s to version %2$s is available." : "Доступно обновление для %1$s до версии %2$s.",
    "Update for {app} to version %s is available." : "Доступно обновление для {app} до версии %s",
    "Update notification" : "Уведомление об обновлении",
    "A new version is available: %s" : "Доступна новая версия: %s",
    "Open updater" : "Открыть окно обновления",
    "Download now" : "Скачать сейчас",
    "The update check is not yet finished. Please refresh the page." : "Проверка обновлений ещё не закончена. Пожалуйста обновите страницу.",
    "Your version is up to date." : "Версия не требует обновления.",
    "Checked on %s" : "Проверено %s",
    "A non-default update server is in use to be checked for updates:" : "Не сервер по умолчанию используется как сервер для проверки обновлений:",
    "Update channel:" : "Канал обновлений:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Вы всегда можете переключиться на экспериментальный канал обновлений для получения новейших версий. Но учтите, что вы не сможете переключиться обратно на канал обновлений для стабильных версий.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Обратите внимание, что от момента выпуска новой версии до её появления здесь может пройти   некоторое время. Мы растягиваем во времени распространение новых версий и иногда, при обнаружении проблем, пропускаем версию.",
    "Notify members of the following groups about available updates:" : "Уведомить членов следующих групп о наличии доступных обновлений:",
    "Only notification for app updates are available." : "Только уведомления об обновлении приложений доступны.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Выбранный канал обновлений высылает специальные уведомления, если сервер устарел.",
    "The selected update channel does not support updates of the server." : "Выбранный канал обновлений не поддерживает обновление сервера."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/ru.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Уведомления об обновлениях",
    "Could not start updater, please try the manual update" : "Не удалось обновить. Пожалуйста, выполните обновление вручную.",
    "{version} is available. Get more information on how to update." : "Доступна версия {version}. Получить дополнительную информацию о порядке обновления.",
    "Channel updated" : "Канал обновлен.",
    "The update server could not be reached since %d days to check for new updates." : "Сервер обновлений недоступен для проверки наличия обновлений дней: %d.",
    "Please check the Nextcloud and server log files for errors." : "Проверьте наличие ошибок в файлах журналов Nextcloud и сервера.",
    "Update to %1$s is available." : "Доступно обновление до версии %1$s.",
    "Update for %1$s to version %2$s is available." : "Для %1$s доступно обновление до версии %2$s.",
    "Update for {app} to version %s is available." : "Для приложения «{app}» доступно обновление до версии %s.",
    "A new version is available: %s" : "Доступна новая версия: %s",
    "Open updater" : "Открыть окно обновления",
    "Download now" : "Скачать сейчас",
    "The update check is not yet finished. Please refresh the page." : "Проверка обновлений ещё не закончена. Пожалуйста обновите страницу.",
    "Your version is up to date." : "Версия не требует обновления.",
    "Checked on %s" : "Проверено %s",
    "A non-default update server is in use to be checked for updates:" : "Не сервер по умолчанию используется как сервер для проверки обновлений:",
    "Update channel:" : "Канал обновлений:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Вы всегда можете переключиться на экспериментальный канал обновлений для получения новейших версий. Но учтите, что вы не сможете переключиться обратно на канал обновлений для стабильных версий.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Обратите внимание, что от момента выпуска новой версии до её появления здесь может пройти   некоторое время. Мы растягиваем во времени распространение новых версий и иногда, при обнаружении проблем, пропускаем версию.",
    "Notify members of the following groups about available updates:" : "Уведомить членов следующих групп о наличии доступных обновлений:",
    "Only notification for app updates are available." : "Только уведомления об обновлении приложений доступны.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Выбранный канал обновлений высылает специальные уведомления, если сервер устарел.",
    "The selected update channel does not support updates of the server." : "Выбранный канал обновлений не поддерживает обновление сервера."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
